@@ -4,16 +4,16 @@
 ###############################################################################
 
 
-setMethod("toJSON", "character",
-	function(x, container = TRUE, collapse = "\n", digits = 5, ..., .level = 1L, .withNames=F) {
+setMethod("asJSON", "character",
+	function(x, container = TRUE, collapse = "\n", digits = 5, ...) {
 		
 		tmp <- x
 		tmp = gsub('\\', '\\\\', tmp, fixed=T);
 		tmp = gsub("\"", "\\\"", tmp, fixed=T);
-		tmp = gsub("\n", "\\\n", tmp, fixed=T);
-		tmp = gsub("\r", "\\\r", tmp, fixed=T);
-		tmp = gsub("\t", "\\\t", tmp, fixed=T);
-		tmp = gsub("\a", "\\\a", tmp, fixed=T);
+		tmp = gsub("\n", "\\n", tmp, fixed=T);
+		tmp = gsub("\r", "\\r", tmp, fixed=T);
+		tmp = gsub("\t", "\\t", tmp, fixed=T);
+		tmp = gsub("\a", "\\a", tmp, fixed=T);
 		
 		tmp = dQuote(tmp);
 		
